@@ -5,13 +5,14 @@
 Language
 </category>
 
-<name>  
+<name>
 Hebrew_LO_Latest_full
 </name>
 
-<description>  
+<description>
    <am>Hebrew Language Meta-Package for LibreOffice</am>
    <ar>Hebrew Language Meta-Package for LibreOffice</ar>
+   <be>Hebrew Language Meta-Package for LibreOffice</be>
    <bg>Hebrew Language Meta-Package for LibreOffice</bg>
    <bn>Hebrew Language Meta-Package for LibreOffice</bn>
    <ca>Metpaquet d'idioma Hebreu per LibreOffice</ca>
@@ -20,13 +21,16 @@ Hebrew_LO_Latest_full
    <de>Hebräisches Meta-Paket für LibreOffice</de>
    <el>LibreOffice στα Εβραϊκά</el>
    <en>Hebrew Language Meta-Package for LibreOffice</en>
-   <es>Meta-Paquete de idioma hebreo para LibreOffice</es>
+   <es_ES>Meta-Paquete de idioma Hebreo para LibreOffice</es_ES>
+   <es>Metapaquete de idioma Hebreo para LibreOffice</es>
    <et>Hebrew Language Meta-Package for LibreOffice</et>
    <eu>Hebrew Language Meta-Package for LibreOffice</eu>
    <fa>Hebrew Language Meta-Package for LibreOffice</fa>
    <fil_PH>Hebrew Language Meta-Package for LibreOffice</fil_PH>
-   <fi>Hebrew Language Meta-Package for LibreOffice</fi>
-   <fr>Hebrew Language Meta-Package for LibreOffice</fr>
+   <fi>Hepreankielinen kielipaketti LibreOffice:lle</fi>
+   <fr_BE>Hebrew Language Meta-Package for LibreOffice</fr_BE>
+   <fr>Méta-Paquet en langue hébraïque pour LibreOffice</fr>
+   <gl_ES>Hebreo Meta-paquete de Idioma para LibreOffice</gl_ES>
    <he_IL>Hebrew Language Meta-Package for LibreOffice</he_IL>
    <hi>Hebrew Language Meta-Package for LibreOffice</hi>
    <hr>Hebrew Language Meta-Package for LibreOffice</hr>
@@ -34,17 +38,18 @@ Hebrew_LO_Latest_full
    <id>Hebrew Language Meta-Package for LibreOffice</id>
    <is>Hebrew Language Meta-Package for LibreOffice</is>
    <it>Meta-pacchetto della lingua ebraica per LibreOffice</it>
-   <ja_JP>Hebrew Language Meta-Package for LibreOffice</ja_JP>
-   <ja>Hebrew Language Meta-Package for LibreOffice</ja>
+   <ja>LibreOffice用のヘブライ語メタパッケージ</ja>
    <kk>Hebrew Language Meta-Package for LibreOffice</kk>
    <ko>Hebrew Language Meta-Package for LibreOffice</ko>
    <lt>Hebrew Language Meta-Package for LibreOffice</lt>
    <mk>Hebrew Language Meta-Package for LibreOffice</mk>
    <mr>Hebrew Language Meta-Package for LibreOffice</mr>
-   <nb>Hebrew Language Meta-Package for LibreOffice</nb>
+   <nb_NO>Hebrew Language Meta-Package for LibreOffice</nb_NO>
+   <nb>Hebraisk språkpakke for LibreOffice</nb>
+   <nl_BE>Hebrew Language Meta-Package for LibreOffice</nl_BE>
    <nl>Hebreews Taal Meta-Pakket voor LibreOffice</nl>
-   <pl>Hebrew Language Meta-Package for LibreOffice</pl>
-   <pt_BR>Hebrew Language Meta-Package for LibreOffice</pt_BR>
+   <pl>Meta-pakiet języka hebrajskiego dla LibreOffice</pl>
+   <pt_BR>Hebraico Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Hebreu Meta-Pacote de Idioma para LibreOffice</pt>
    <ro>Hebrew Language Meta-Package for LibreOffice</ro>
    <ru>Hebrew Language Meta-Package for LibreOffice</ru>
@@ -53,10 +58,12 @@ Hebrew_LO_Latest_full
    <sq>Hebrew Language Meta-Package for LibreOffice</sq>
    <sr>Hebrew Language Meta-Package for LibreOffice</sr>
    <sv>Hebreiskt Språk Meta-Paket för LibreOffice</sv>
-   <tr>Hebrew Language Meta-Package for LibreOffice</tr>
+   <th>Meta-Package ภาษา Hebrew สำหรับ LibreOffice</th>
+   <tr>LibreOffice için İbranice Dili Üst-Paketi</tr>
    <uk>Hebrew Language Meta-Package for LibreOffice</uk>
    <vi>Hebrew Language Meta-Package for LibreOffice</vi>
-   <zh_CN>Hebrew Language Meta-Package for LibreOffice</zh_CN>
+   <zh_CN>LibreOffice 希伯来语语言包</zh_CN>
+   <zh_HK>Hebrew Language Meta-Package for LibreOffice</zh_HK>
    <zh_TW>Hebrew Language Meta-Package for LibreOffice</zh_TW>
 </description>
 
