@@ -5,13 +5,14 @@
 Language
 </category>
 
-<name>  
+<name>
 Mongolian_LO_Latest_full
 </name>
 
-<description>  
+<description>
    <am>Mongolian Language Meta-Package for LibreOffice</am>
    <ar>Mongolian Language Meta-Package for LibreOffice</ar>
+   <be>Mongolian Language Meta-Package for LibreOffice</be>
    <bg>Mongolian Language Meta-Package for LibreOffice</bg>
    <bn>Mongolian Language Meta-Package for LibreOffice</bn>
    <ca>Metapaquet d'idioma Mongol per LibreOffice</ca>
@@ -20,13 +21,16 @@ Mongolian_LO_Latest_full
    <de>Mongolisches Meta-Paket für LibreOffice</de>
    <el>LibreOffice στα Mongolian</el>
    <en>Mongolian Language Meta-Package for LibreOffice</en>
-   <es>Metapaquete de idioma mongol para LibreOffice</es>
+   <es_ES>Meta-Paquete de idioma Mongol para LibreOffice</es_ES>
+   <es>Metapaquete de idioma Mongol para LibreOffice</es>
    <et>Mongolian Language Meta-Package for LibreOffice</et>
    <eu>Mongolian Language Meta-Package for LibreOffice</eu>
    <fa>Mongolian Language Meta-Package for LibreOffice</fa>
    <fil_PH>Mongolian Language Meta-Package for LibreOffice</fil_PH>
-   <fi>Mongolian Language Meta-Package for LibreOffice</fi>
-   <fr>Mongolian Language Meta-Package for LibreOffice</fr>
+   <fi>Mongolialainen kielipaketti LibreOffice:lle</fi>
+   <fr_BE>Mongolian Language Meta-Package for LibreOffice</fr_BE>
+   <fr>Méta-Paquet en langue mongole pour LibreOffice</fr>
+   <gl_ES>Mongol Meta-paquete de Idioma para LibreOffice</gl_ES>
    <he_IL>Mongolian Language Meta-Package for LibreOffice</he_IL>
    <hi>Mongolian Language Meta-Package for LibreOffice</hi>
    <hr>Mongolian Language Meta-Package for LibreOffice</hr>
@@ -34,17 +38,18 @@ Mongolian_LO_Latest_full
    <id>Mongolian Language Meta-Package for LibreOffice</id>
    <is>Mongolian Language Meta-Package for LibreOffice</is>
    <it>Meta-pacchetto della lingua mongola per LibreOffice</it>
-   <ja_JP>Mongolian Language Meta-Package for LibreOffice</ja_JP>
-   <ja>Mongolian Language Meta-Package for LibreOffice</ja>
+   <ja>LibreOffice用モンゴル語メタパッケージ</ja>
    <kk>Mongolian Language Meta-Package for LibreOffice</kk>
    <ko>Mongolian Language Meta-Package for LibreOffice</ko>
    <lt>Mongolian Language Meta-Package for LibreOffice</lt>
    <mk>Mongolian Language Meta-Package for LibreOffice</mk>
    <mr>Mongolian Language Meta-Package for LibreOffice</mr>
-   <nb>Mongolian Language Meta-Package for LibreOffice</nb>
+   <nb_NO>Mongolian Language Meta-Package for LibreOffice</nb_NO>
+   <nb>Mongolsk språkpakke for LibreOffice</nb>
+   <nl_BE>Mongolian Language Meta-Package for LibreOffice</nl_BE>
    <nl>Mongools Taal Meta-Pakket voor LibreOffice</nl>
-   <pl>Mongolian Language Meta-Package for LibreOffice</pl>
-   <pt_BR>Mongolian Language Meta-Package for LibreOffice</pt_BR>
+   <pl>Mongolski meta-pakiet językowy dla LibreOffice</pl>
+   <pt_BR>Mongol Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Mongol Meta-Pacote de Idioma para LibreOffice</pt>
    <ro>Mongolian Language Meta-Package for LibreOffice</ro>
    <ru>Mongolian Language Meta-Package for LibreOffice</ru>
@@ -53,10 +58,12 @@ Mongolian_LO_Latest_full
    <sq>Mongolian Language Meta-Package for LibreOffice</sq>
    <sr>Mongolian Language Meta-Package for LibreOffice</sr>
    <sv>Mongoliskt Språk Meta-Paket för LibreOffice</sv>
-   <tr>Mongolian Language Meta-Package for LibreOffice</tr>
+   <th>Meta-Package ภาษา Mongolian สำหรับ LibreOffice</th>
+   <tr>LibreOffice için Moğolca Dili Üst-Paketi</tr>
    <uk>Mongolian Language Meta-Package for LibreOffice</uk>
    <vi>Mongolian Language Meta-Package for LibreOffice</vi>
    <zh_CN>Mongolian Language Meta-Package for LibreOffice</zh_CN>
+   <zh_HK>Mongolian Language Meta-Package for LibreOffice</zh_HK>
    <zh_TW>Mongolian Language Meta-Package for LibreOffice</zh_TW>
 </description>
 
